@@ -1,5 +1,6 @@
 import hashlib
 import re
+import sys
 import textwrap
 
 from pytype import utils
@@ -1220,15 +1221,8 @@ class FunctionTest(_ParserTestBase):
 
   def test_decorated_class(self):
     self.check("""
-      from dataclasses import dataclass
-
-      @dataclass
+      @decorator
       class Foo: ...
-    """, """
-    from dataclasses import dataclass
-
-    @dataclass
-    class Foo: ...
     """)
 
   def test_multiple_class_decorators(self):
@@ -1244,6 +1238,33 @@ class FunctionTest(_ParserTestBase):
       class Foo: ...
     """, 1, "Unsupported class decorators: classmethod")
 
+  def test_dataclass_decorator(self):
+    self.check("""
+      from dataclasses import dataclass
+
+      @dataclass
+      class Foo:
+        x: int
+        y: str = ...
+    """, """
+    from dataclasses import dataclass
+
+    @dataclass
+    class Foo:
+        x: int
+        y: str
+        def __init__(self, x: int, y: str = ...) -> None: ...
+    """)
+
+  def test_dataclass_default_error(self):
+    self.check_error("""
+      from dataclasses import dataclass
+      @dataclass
+      class Foo:
+        x: int = ...
+        y: str
+    """, None, "non-default argument y follows default arguments")
+
   def test_empty_body(self):
     self.check("def foo() -> int: ...")
     self.check("def foo() -> int: ...",
@@ -2690,5 +2711,44 @@ class MethodAliasTest(_ParserTestBase):
     """)
 
 
+class ErrorTest(test_base.UnitTest):
+  """Test parser errors."""
+
+  def test_filename(self):
+    src = textwrap.dedent("""
+      a: int
+      a: int
+    """)
+    with self.assertRaisesRegex(parser.ParseError, "File.*foo.pyi"):
+      parser.parse_pyi(src, "foo.pyi", "foo", (3, 6))
+
+  def test_lineno(self):
+    src = textwrap.dedent("""
+      class A:
+        __slots__ = 0
+    """)
+    with self.assertRaisesRegex(parser.ParseError, "line 3"):
+      parser.parse_pyi(src, "foo.py", "foo", (3, 6))
+
+
+class ParamsTest(test_base.UnitTest):
+  """Test input parameter handling."""
+
+  def test_feature_version(self):
+    cases = [
+        [2, 6],
+        [(2,), 6],
+        [(2, 7), 6],
+        [(2, 7, 8), 6],
+        [3, sys.version_info.minor],
+        [(3,), sys.version_info.minor],
+        [(3, 7), 7],
+        [(3, 8, 2), 8]
+    ]
+    for version, expected in cases:
+      actual = parser._feature_version(version)
+      self.assertEqual(actual, expected)
+
+
 if __name__ == "__main__":
   unittest.main()
